Library for Siemens SDA5708 8 digit LED matrix display. The control interface is SPI.

Dependents:   mbed_SDA5708

Revision:
5:c0f8118deca2
Parent:
4:7713c496717b
Child:
6:27200bf65974
--- a/SDA5708.h	Tue Sep 30 18:14:31 2014 +0000
+++ b/SDA5708.h	Tue Sep 30 18:27:40 2014 +0000
@@ -107,24 +107,21 @@
  * @endcode
  */
 
-
-//#if(SDA5708_PRINTF == 1)
+#if DOXYGEN_ONLY
 /** Create an SDA5708 Display object connected to the proper pins
  *
  * @param  *spi SPI port
  * @param  cs   PinName for Chip Select (active low)
  * @param  rst  PinName for Reset (active low)
 */
+class SDA5708 {
+#endif
+
+#if (SDA5708_PRINTF == 1)
 class SDA5708 : public Stream {  
-//#else    
-///** Create an SDA5708 Display object connected to the proper pins
-// *
-// * @param  *spi SPI port
-// * @param  cs   PinName for Chip Select (active low)
-// * @param  rst  PinName for Reset (active low)
-//*/
-//class SDA5708 {
-//#endif
+#else    
+class SDA5708 {
+#endif
 
 public:
 
@@ -143,21 +140,21 @@
    SDA5708(SPI *spi, PinName cs, PinName rst);
   
 #if(SDA5708_PRINTF != 1)
-   /** Write a character to the LCD
+   /** Write a character to the Display
      *
      * @param c The character to write to the display
      */
    int putc(int c);
 
-    /** Write a raw string to the LCD
+    /** Write a raw string to the Display
      *
      * @param string text, may be followed by variables to emulate formatting the string.
      *                     However, printf formatting is NOT supported and variables will be ignored! 
      */
     int printf(const char* text, ...);
 #else    
 #if DOXYGEN_ONLY
-    /** Write a character to the LCD
+    /** Write a character to the Display
      *
      * @param c The character to write to the display
      */
@@ -143,21 +140,21 @@
      *
      * @param string text, may be followed by variables to emulate formatting the string.
-     *                     However, printf formatting is NOT supported and variables will be ignored! 
+     *                     However, when (SDA5708_PRINTF != 1) then printf formatting is NOT supported and variables will be ignored!           
      */
     int printf(const char* text, ...);